==> deepin-home_1.6.4.tar.xz: BUILD/translations/deepin-home/es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>API</name>
    <message>
        <source>Please log in with your Deepin ID.</source>
        <translation>Inicie sesión con su ID de Deepin.</translation>
    </message>
    <message>
        <source>You need to log in to proceed with the subsequent operations.</source>
        <translation>Para continuar debe iniciar sesión.</translation>
    </message>
</context>
<context>
    <name>APIProxy</name>
    <message>
        <source>You have been making too many requests, Please try again later.</source>
        <translation>Has hacho demasiadas solicitudes. inténtelo de nuevo más tarde.</translation>
    </message>
    <message>
        <source>You need to login to proceed with the subsequent operations.</source>
        <translation>Para continuar debe iniciar sesión.</translation>
    </message>
    <message>
        <source>Network error, please try later.</source>
        <translation>Error de red, por favor intente mas tarde</translation>
    </message>
</context>
<context>
    <name>AccountButton</name>
    <message>
        <source>Unlogged</source>
        <translation>No registrado</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>Mis favoritos</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>Mis comentarios</translation>
    </message>
    <message>
        <source>Sign out</source>
        <translation>Cerrar sesión </translation>
    </message>
    <message>
        <source>Sign in</source>
        <translation>Iniciar sesión</translation>
    </message>
</context>
<context>
    <name>Card</name>
    <message>
        <source>%1 views</source>
        <translation>%1 visualizaciones</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Sugerencias</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>No favoritos</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <source>Cancel the urge</source>
        <translation>Cancelar pedido</translation>
    </message>
    <message>
        <source>Urge</source>
        <translation>Solicitar</translation>
    </message>
</context>
<context>
    <name>Card1</name>
    <message>
        <source>Coming</source>
        <translation>Próximamente</translation>
    </message>
</context>
<context>
    <name>Detail</name>
    <message>
        <source>Official response</source>
        <translation>Respuesta oficial</translation>
    </message>
</context>
<context>
    <name>Filter</name>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Todo</translation>
    </message>
    <message>
        <source>Bug</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Sugerencias</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Versión:</translation>
    </message>
    <message>
        <source>Sort:</source>
        <translation>Clasificar:</translation>
    </message>
    <message>
        <source>Newest</source>
        <translation>Lo mas nuevo</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <source>Urge</source>
        <translation>Solicitar</translation>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <source>Communication</source>
        <translation>Comunicación</translation>
    </message>
    <message>
        <source>Discuss and share here</source>
        <translation>Discuta y comparta aquí</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Informe de errores</translation>
    </message>
    <message>
        <source>Report issues you found</source>
        <translation>Informar de los problemas encontrados</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Sugerencias</translation>
    </message>
    <message>
        <source>Submit your suggestions</source>
        <translation>Envíe sus sugerencias</translation>
    </message>
    <message>
        <source>Resources</source>
        <translation>Recursos</translation>
    </message>
    <message>
        <source>Questionaire</source>
        <translation>Cuestionario</translation>
    </message>
    <message>
        <source>Join US</source>
        <translation>Únase a nosotros</translation>
    </message>
    <message>
        <source>Internal Testing</source>
        <translation>Pruebas internas</translation>
    </message>
    <message>
        <source>Global Translation</source>
        <translation>Traducción global</translation>
    </message>
    <message>
        <source>Community News</source>
        <translation>Noticias de la Comunidad</translation>
    </message>
</context>
<context>
    <name>List</name>
    <message>
        <source>No more items</source>
        <translation>No hay más artículos</translation>
    </message>
    <message>
        <source>Messages</source>
        <translation>Mensajes</translation>
    </message>
    <message>
        <source>Questionaires</source>
        <translation>Preguntas</translation>
    </message>
</context>
<context>
    <name>MyTitleBar</name>
    <message>
        <source>Launch at system startup</source>
        <translation>Lanzar al inicio del sistema</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <source>Deepin Home</source>
        <translation>Centro de comentarios</translation>
    </message>
    <message>
        <source>Quick login to forums, submit suggestions, and report bugs.</source>
        <translation>Inicio de sesión rápido en foros, envío de sugerencias e informe de errores.</translation>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <source>No messages yet.</source>
        <translation>Todavía no hay mensajes.</translation>
    </message>
    <message>
        <source>%1 messages</source>
        <translation>%1 mensajes</translation>
    </message>
    <message>
        <source>Mark all as read</source>
        <translation>Marcar todo como leído</translation>
    </message>
</context>
<context>
    <name>NotifyDetail</name>
    <message>
        <source>View more</source>
        <translation>Ver más</translation>
    </message>
</context>
<context>
    <name>Offline</name>
    <message>
        <source>Network error, please try later</source>
        <translation>Error de red, por favor intente mas tarde</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Actualizar</translation>
    </message>
</context>
<context>
    <name>Preload</name>
    <message>
        <source>Deepin Home</source>
        <translation>Centro de comentarios</translation>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <source>No questionaires yet.</source>
        <translation>Todavía no hay cuestionarios.</translation>
    </message>
    <message>
        <source>Expired on: %1</source>
        <translation>Expirado el: %1</translation>
    </message>
    <message>
        <source>Fill In</source>
        <translation>Rellenar</translation>
    </message>
</context>
<context>
    <name>Status</name>
    <message>
        <source>Pending</source>
        <translation>Pendiente</translation>
    </message>
    <message>
        <source>Reproducing</source>
        <translation>Reproduciendo</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Confirmado</translation>
    </message>
    <message>
        <source>Replied</source>
        <translation>Respuesta</translation>
    </message>
    <message>
        <source>Resolved</source>
        <translation>Resuelto</translation>
    </message>
    <message>
        <source>Evaluating</source>
        <translation>En evaluación </translation>
    </message>
    <message>
        <source>Accepted</source>
        <translation>Aceptado</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Terminado</translation>
    </message>
    <message>
        <source>The issue has not been processed and will not be displayed in the public listing.</source>
        <translation>El pedido no se ha procesado y no se mostrará en la lista pública.</translation>
    </message>
    <message>
        <source>Currently unable to identify the cause; continuous monitoring and investigation are required.</source>
        <translation>Actualmente no se puede identificar la causa; se requiere monitoreo e investigación continuos.</translation>
    </message>
    <message>
        <source>The issue has been reproduced and the root cause has been identified.</source>
        <translation>El problema se ha reproducido y se ha identificado la causa.</translation>
    </message>
    <message>
        <source>The issue is not a bug or of a different nature.</source>
        <translation>El problema no es un error o tiene otras causas.</translation>
    </message>
    <message>
        <source>The issue has been resolved and awaiting formal release</source>
        <translation>El problema se ha resuelto y está pendiente de liberación formal.</translation>
    </message>
    <message>
        <source>The requirement has not been processed and will not be displayed in the public listing</source>
        <translation>El pedido no se ha procesado y no se mostrará en la lista pública.</translation>
    </message>
    <message>
        <source>The issue has been acknowledged and is being internally assessed</source>
        <translation>El problema ha sido reconocido y está siendo evaluado internamente.</translation>
    </message>
    <message>
        <source>Included in the plans for a future release</source>
        <translation>Fue incluido en los planes para una versión futura</translation>
    </message>
    <message>
        <source>The requirement is either not accepted or unable to be addressed</source>
        <translation>El pedido no fue aceptado o no se puede abordar</translation>
    </message>
    <message>
        <source>Development work is finished, awaiting formal release</source>
        <translation>El trabajo de desarrollo está terminado, a la espera del lanzamiento formal.</translation>
    </message>
</context>
<context>
    <name>Submit</name>
    <message>
        <source>Unable to add a screenshot.</source>
        <translation>No se puede agregar una captura de pantalla.</translation>
    </message>
    <message>
        <source>The image file size should be less than 1MB.</source>
        <translation>El tamaño del archivo de imagen debe ser inferior a 1 MB.</translation>
    </message>
    <message>
        <source>The image file format is not supported for uploading.</source>
        <translation>El formato de archivo de imagen no es compatible.</translation>
    </message>
    <message>
        <source>[Current Status of the Product]: 
[Desired Product]: </source>
        <translation>Estado actual del producto]:
[Producto deseado]:</translation>
    </message>
    <message>
        <source>[Preconditions]: 
[Reproducibility Steps]: 
[Expected Results]: 
[Actual Results]: </source>
        <translation>[Condiciones previas]:
[Pasos de reproducibilidad]:
[Resultados previstos]:
[Resultados actuales]:</translation>
    </message>
    <message>
        <source>Submit Feedback</source>
        <translation>Enviar comentario</translation>
    </message>
    <message>
        <source>Type：</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Sugerencias</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Informe de error</translation>
    </message>
    <message>
        <source>Title：</source>
        <translation>Título:</translation>
    </message>
    <message>
        <source>Please provide a brief description of your issue</source>
        <translation>Proporcione una breve descripción de su problema</translation>
    </message>
    <message>
        <source>Content：</source>
        <translation>Contenido:</translation>
    </message>
    <message>
        <source>Do not fill in multiple issues in one feedback</source>
        <translation>No rellene varias cuestiones en una sola respuesta</translation>
    </message>
    <message>
        <source>Do not fill in multiple requirements in one feedback</source>
        <translation>No envié múltiples pedidos en un solo comentario</translation>
    </message>
    <message>
        <source>Email：</source>
        <translation>Correo electrónico:</translation>
    </message>
    <message>
        <source>Please enter your email</source>
        <translation>Introduzca su correo electrónico</translation>
    </message>
    <message>
        <source>System Version:</source>
        <translation>Versión del sistema:</translation>
    </message>
    <message>
        <source>Device Info：</source>
        <translation>Información del dispositivo:</translation>
    </message>
    <message>
        <source>Upload &lt;a href=&apos;home://sysinfo&apos;&gt;device information&lt;/a&gt;</source>
        <translation>Subir &lt;a href=&apos;home://sysinfo&apos;&gt;información del dispositivo&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Screenshots：</source>
        <translation>Capturas de pantalla:</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation>Archivos de imagen</translation>
    </message>
    <message>
        <source>Drag and drop files or click buttons to add pictures, up to three</source>
        <translation>Arrastre y suelte archivos o haga clic en los botones para agregar imágenes, hasta tres</translation>
    </message>
    <message>
        <source>Are you sure you want to exit the feedback submission?</source>
        <translation>¿Está seguro de que desea salir del envío de comentarios?</translation>
    </message>
    <message>
        <source>The feedback content will not be saved.</source>
        <translation>El contenido de los comentarios no se guardará.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <source>Submit</source>
        <translation>Enviar</translation>
    </message>
    <message>
        <source>Unable to submit feedback.</source>
        <translation>No se puede enviar el comentario.</translation>
    </message>
    <message>
        <source>Please provide the title and content of your feedback.</source>
        <translation>Proporcione el título y el contenido de sus comentario.</translation>
    </message>
    <message>
        <source>Please provide the title of your feedback.</source>
        <translation>Proporcione el título de su comentario.</translation>
    </message>
    <message>
        <source>Please provide the content of your feedback.</source>
        <translation>Proporcione el contenido de su comentario.</translation>
    </message>
    <message>
        <source>Incorrect email address entered.</source>
        <translation>Se ingresó una dirección de correo electrónico incorrecta.</translation>
    </message>
    <message>
        <source>Device Information</source>
        <translation>Información del dispositivo</translation>
    </message>
</context>
<context>
    <name>TabButton</name>
    <message>
        <source>Feedback Hub</source>
        <translation>Centro de comentarios</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>Mis comentarios</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>Mis favoritos</translation>
    </message>
    <message>
        <source>My Urged</source>
        <translation>Mis envíos</translation>
    </message>
</context>
</TS>

==> deepin-home_1.6.5.tar.xz: BUILD/translations/deepin-home/es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>API</name>
    <message>
        <source>Please log in with your Deepin ID.</source>
        <translation>Inicie sesión con su Deepin ID.</translation>
    </message>
    <message>
        <source>You need to log in to proceed with the subsequent operations.</source>
        <translation>Para continuar debe iniciar sesión.</translation>
    </message>
</context>
<context>
    <name>APIProxy</name>
    <message>
        <source>You have been making too many requests, Please try again later.</source>
        <translation>Ha hecho demasiadas solicitudes. inténtelo de nuevo más tarde.</translation>
    </message>
    <message>
        <source>You need to login to proceed with the subsequent operations.</source>
        <translation>Para continuar debe iniciar sesión.</translation>
    </message>
    <message>
        <source>Network error, please try later.</source>
        <translation>Error de red, por favor intente mas tarde</translation>
    </message>
</context>
<context>
    <name>AccountButton</name>
    <message>
        <source>Unlogged</source>
        <translation>No registrado</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>Mis favoritos</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>Mis comentarios</translation>
    </message>
    <message>
        <source>Sign out</source>
        <translation>Cerrar sesión </translation>
    </message>
    <message>
        <source>Sign in</source>
        <translation>Iniciar sesión</translation>
    </message>
</context>
<context>
    <name>Card</name>
    <message>
        <source>%1 views</source>
        <translation>%1 visualizaciones</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Sugerencias</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>No favoritos</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <source>Cancel the urge</source>
        <translation>Cancelar pedido</translation>
    </message>
    <message>
        <source>Urge</source>
        <translation>Solicitar</translation>
    </message>
</context>
<context>
    <name>Card1</name>
    <message>
        <source>Coming</source>
        <translation>Próximamente</translation>
    </message>
</context>
<context>
    <name>Detail</name>
    <message>
        <source>Official response</source>
        <translation>Respuesta oficial</translation>
    </message>
</context>
<context>
    <name>Filter</name>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Todo</translation>
    </message>
    <message>
        <source>Bug</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Sugerencias</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Versión:</translation>
    </message>
    <message>
        <source>Sort:</source>
        <translation>Clasificar:</translation>
    </message>
    <message>
        <source>Newest</source>
        <translation>Lo mas nuevo</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <source>Urge</source>
        <translation>Solicitar</translation>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <source>Communication</source>
        <translation>Comunicación</translation>
    </message>
    <message>
        <source>Discuss and share here</source>
        <translation>Discuta y comparta aquí</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Informe de errores</translation>
    </message>
    <message>
        <source>Report issues you found</source>
        <translation>Informar de los problemas encontrados</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Sugerencias</translation>
    </message>
    <message>
        <source>Submit your suggestions</source>
        <translation>Envíe sus sugerencias</translation>
    </message>
    <message>
        <source>Resources</source>
        <translation>Recursos</translation>
    </message>
    <message>
        <source>Questionaire</source>
        <translation>Cuestionario</translation>
    </message>
    <message>
        <source>Join US</source>
        <translation>Únase a nosotros</translation>
    </message>
    <message>
        <source>Internal Testing</source>
        <translation>Pruebas internas</translation>
    </message>
    <message>
        <source>Global Translation</source>
        <translation>Traducción global</translation>
    </message>
    <message>
        <source>Community News</source>
        <translation>Noticias de la Comunidad</translation>
    </message>
</context>
<context>
    <name>List</name>
    <message>
        <source>No more items</source>
        <translation>No hay más artículos</translation>
    </message>
    <message>
        <source>Messages</source>
        <translation>Mensajes</translation>
    </message>
    <message>
        <source>Questionaires</source>
        <translation>Preguntas</translation>
    </message>
</context>
<context>
    <name>MyTitleBar</name>
    <message>
        <source>Launch at system startup</source>
        <translation>Lanzar al inicio del sistema</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <source>Deepin Home</source>
        <translation>Centro de comentarios</translation>
    </message>
    <message>
        <source>Quick login to forums, submit suggestions, and report bugs.</source>
        <translation>Inicio de sesión rápido en foros, envío de sugerencias e informe de errores.</translation>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <source>No messages yet.</source>
        <translation>Todavía no hay mensajes.</translation>
    </message>
    <message>
        <source>%1 messages</source>
        <translation>%1 mensajes</translation>
    </message>
    <message>
        <source>Mark all as read</source>
        <translation>Marcar todo como leído</translation>
    </message>
</context>
<context>
    <name>NotifyDetail</name>
    <message>
        <source>View more</source>
        <translation>Ver más</translation>
    </message>
</context>
<context>
    <name>Offline</name>
    <message>
        <source>Network error, please try later</source>
        <translation>Error de red, por favor intente mas tarde</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Actualizar</translation>
    </message>
</context>
<context>
    <name>Preload</name>
    <message>
        <source>Deepin Home</source>
        <translation>Centro de comentarios</translation>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <source>No questionaires yet.</source>
        <translation>Todavía no hay cuestionarios.</translation>
    </message>
    <message>
        <source>Expired on: %1</source>
        <translation>Expirado el: %1</translation>
    </message>
    <message>
        <source>Fill In</source>
        <translation>Rellenar</translation>
    </message>
</context>
<context>
    <name>Status</name>
    <message>
        <source>Pending</source>
        <translation>Pendiente</translation>
    </message>
    <message>
        <source>Reproducing</source>
        <translation>Reproduciendo</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Confirmado</translation>
    </message>
    <message>
        <source>Replied</source>
        <translation>Respuesta</translation>
    </message>
    <message>
        <source>Resolved</source>
        <translation>Resuelto</translation>
    </message>
    <message>
        <source>Evaluating</source>
        <translation>En evaluación </translation>
    </message>
    <message>
        <source>Accepted</source>
        <translation>Aceptado</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Terminado</translation>
    </message>
    <message>
        <source>The issue has not been processed and will not be displayed in the public listing.</source>
        <translation>El pedido no se ha procesado y no se mostrará en la lista pública.</translation>
    </message>
    <message>
        <source>Currently unable to identify the cause; continuous monitoring and investigation are required.</source>
        <translation>Actualmente no se puede identificar la causa; se requiere monitoreo e investigación continuos.</translation>
    </message>
    <message>
        <source>The issue has been reproduced and the root cause has been identified.</source>
        <translation>El problema se ha reproducido y se ha identificado la causa.</translation>
    </message>
    <message>
        <source>The issue is not a bug or of a different nature.</source>
        <translation>El problema no es un error o tiene otras causas.</translation>
    </message>
    <message>
        <source>The issue has been resolved and awaiting formal release</source>
        <translation>El problema se ha resuelto y está pendiente de liberación formal.</translation>
    </message>
    <message>
        <source>The requirement has not been processed and will not be displayed in the public listing</source>
        <translation>El pedido no se ha procesado y no se mostrará en la lista pública.</translation>
    </message>
    <message>
        <source>The issue has been acknowledged and is being internally assessed</source>
        <translation>El problema ha sido reconocido y está siendo evaluado internamente.</translation>
    </message>
    <message>
        <source>Included in the plans for a future release</source>
        <translation>Fue incluido en los planes para una versión futura</translation>
    </message>
    <message>
        <source>The requirement is either not accepted or unable to be addressed</source>
        <translation>El pedido no fue aceptado o no se puede abordar</translation>
    </message>
    <message>
        <source>Development work is finished, awaiting formal release</source>
        <translation>El trabajo de desarrollo está terminado, a la espera del lanzamiento formal.</translation>
    </message>
</context>
<context>
    <name>Submit</name>
    <message>
        <source>Unable to add a screenshot.</source>
        <translation>No se puede añadir una captura de pantalla.</translation>
    </message>
    <message>
        <source>The image file size should be less than 1MB.</source>
        <translation>El tamaño del archivo de imagen debe ser inferior a 1 MB.</translation>
    </message>
    <message>
        <source>The image file format is not supported for uploading.</source>
        <translation>El formato de archivo de imagen no es compatible.</translation>
    </message>
    <message>
        <source>[Current Status of the Product]: 
[Desired Product]: </source>
        <translation>Estado actual del producto]:
[Producto deseado]:</translation>
    </message>
    <message>
        <source>[Preconditions]: 
[Reproducibility Steps]: 
[Expected Results]: 
[Actual Results]: </source>
        <translation>[Condiciones previas]:
[Pasos de reproducibilidad]:
[Resultados previstos]:
[Resultados actuales]:</translation>
    </message>
    <message>
        <source>Submit Feedback</source>
        <translation>Enviar comentario</translation>
    </message>
    <message>
        <source>Type：</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Sugerencias</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Informe de error</translation>
    </message>
    <message>
        <source>Title：</source>
        <translation>Título:</translation>
    </message>
    <message>
        <source>Please provide a brief description of your issue</source>
        <translation>Proporcione una breve descripción de su problema</translation>
    </message>
    <message>
        <source>Content：</source>
        <translation>Contenido:</translation>
    </message>
    <message>
        <source>Do not fill in multiple issues in one feedback</source>
        <translation>No rellene varias cuestiones en una sola respuesta</translation>
    </message>
    <message>
        <source>Do not fill in multiple requirements in one feedback</source>
        <translation>No envié múltiples pedidos en un solo comentario</translation>
    </message>
    <message>
        <source>Email：</source>
        <translation>Correo electrónico:</translation>
    </message>
    <message>
        <source>Please enter your email</source>
        <translation>Introduzca su correo electrónico</translation>
    </message>
    <message>
        <source>System Version:</source>
        <translation>Versión del sistema:</translation>
    </message>
    <message>
        <source>Device Info：</source>
        <translation>Información del dispositivo:</translation>
    </message>
    <message>
        <source>Upload &lt;a href=&apos;home://sysinfo&apos;&gt;device information&lt;/a&gt;</source>
        <translation>Subir &lt;a href=&apos;home://sysinfo&apos;&gt;información del dispositivo&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Screenshots：</source>
        <translation>Capturas de pantalla:</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation>Archivos de imagen</translation>
    </message>
    <message>
        <source>Drag and drop files or click buttons to add pictures, up to three</source>
        <translation>Arrastre y suelte archivos o haga clic en los botones para añadir imágenes, hasta tres</translation>
    </message>
    <message>
        <source>Are you sure you want to exit the feedback submission?</source>
        <translation>¿Está seguro de que desea salir del envío de comentarios?</translation>
    </message>
    <message>
        <source>The feedback content will not be saved.</source>
        <translation>El contenido de los comentarios no se guardará.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <source>Submit</source>
        <translation>Enviar</translation>
    </message>
    <message>
        <source>Unable to submit feedback.</source>
        <translation>No se puede enviar el comentario.</translation>
    </message>
    <message>
        <source>Please provide the title and content of your feedback.</source>
        <translation>Proporcione el título y el contenido de sus comentario.</translation>
    </message>
    <message>
        <source>Please provide the title of your feedback.</source>
        <translation>Proporcione el título de su comentario.</translation>
    </message>
    <message>
        <source>Please provide the content of your feedback.</source>
        <translation>Proporcione el contenido de su comentario.</translation>
    </message>
    <message>
        <source>Incorrect email address entered.</source>
        <translation>Se ingresó una dirección de correo electrónico incorrecta.</translation>
    </message>
    <message>
        <source>Device Information</source>
        <translation>Información del dispositivo</translation>
    </message>
</context>
<context>
    <name>TabButton</name>
    <message>
        <source>Feedback Hub</source>
        <translation>Centro de comentarios</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>Mis comentarios</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>Mis favoritos</translation>
    </message>
    <message>
        <source>My Urged</source>
        <translation>Mis envíos</translation>
    </message>
</context>
</TS>
